@@ -3,6 +3,7 @@
 #' Constructs an ensemble of logic regression models using bagging for classification or regression, and identifies important predictors and interactions. Logic Forest (LF) efficiently searches the space of logical combinations of binary variables using simulated annealing. It has been extended to support linear and survival regression.
 #' @importFrom LogicReg eval.logreg logreg logreg.anneal.control
 #' @importFrom methods is
+#' @importFrom utils txtProgressBar setTxtProgressBar
 #'
 #' @param resp.type String indicating regression type: \code{"bin"} for classification, \code{"lin"} for linear regression, \code{"exp_surv"} for exponential time-to-event, and \code{"cph_surv"} for Cox proportional hazards.
 #' @param resp Numeric vector of response values (binary for classification/survival, continuous for linear regression). For time-to-event, indicates event/censoring status.
@@ -104,6 +105,7 @@ logforest<-function(resp.type, resp, resp.time = data.frame(X = rep(1, nrow(resp
   if (mtype=="Linear Regression") {mtyp=2}
   if (mtype=="Cox-PH Time-to-Event") {mtyp=3}
   if (mtype=="Exp. Time-to-Event") {mtyp=4}
+  pb <- txtProgressBar(min = 0, max = nBS, style = 3) # Initialize progress bar
   for(b in 1:nBS)
   {
     if(missing(nleaves)) {nleaves<-sample(2:8, 1, replace=FALSE)}
@@ -183,8 +185,11 @@ logforest<-function(resp.type, resp, resp.time = data.frame(X = rep(1, nrow(resp
     fitlist[[b]]<-fit   #list of all models
     IBdata[[b]]<-BSindices #data frame of one vector per BS sample, listing each row in the IB sample
     OOBdata[[b]]<-OOBindices #data frame of one vector per BS sample, listing each row in the OOB sample
+    setTxtProgressBar(pb, b) # Update the progress bar
+
   }
   ###CLOSE  THE BOOTSTAP LOOP
+  close(pb) # Close progress bar
 
   if (mtype=="Classification")
   {
